@@ -16,6 +16,7 @@ from gradio.components import (
     Checkbox,
     Checkboxgroup,
     CheckboxGroup,
+    ColorPicker,
     DataFrame,
     Dataframe,
     Dataset,
@@ -41,6 +42,7 @@ from gradio.components import (
     Video,
     component,
 )
+from gradio.examples import Examples
 from gradio.flagging import (
     CSVLogger,
     FlaggingCallback,
@@ -67,5 +69,5 @@ from gradio.templates import (
     Webcam,
 )
 
-current_pkg_version = pkgutil.get_data(__name__, "version.txt").decode('ascii').strip()
+current_pkg_version = pkgutil.get_data(__name__, "version.txt").decode("ascii").strip()
 __version__ = current_pkg_version
