@@ -25,7 +25,6 @@ from gradio.blocks import Blocks
 from gradio.components import (
     Button,
     Component,
-    Dataset,
     Interpretation,
     IOComponent,
     Markdown,
@@ -33,21 +32,32 @@ from gradio.components import (
     Variable,
     get_component_instance,
 )
+from gradio.documentation import document, set_documentation_group
 from gradio.events import Changeable, Streamable
+from gradio.examples import Examples
 from gradio.external import load_from_pipeline  # type: ignore
 from gradio.flagging import CSVLogger, FlaggingCallback  # type: ignore
 from gradio.layouts import Column, Row, TabItem, Tabs
-from gradio.process_examples import cache_interface_examples, load_from_cache
+
+set_documentation_group("interface")
 
 if TYPE_CHECKING:  # Only import for type checking (is False at runtime).
     import transformers
 
 
+@document("launch", "load", "from_pipeline")
 class Interface(Blocks):
     """
     The Interface class is a high-level abstraction that allows you to create a
     web-based demo around a machine learning model or arbitrary Python function
     by specifying: (1) the function (2) the desired input components and (3) desired output components.
+    Example:
+        import gradio as gr
+        def image_classifier(inp):
+            return {'cat': 0.3, 'dog': 0.7}
+        demo = gr.Interface(fn=image_classifier, inputs="image", outputs="label")
+        demo.launch(share=True)
+    Demos: hello_world, hello_world_3, gpt_j
     """
 
     # stores references to all currently existing Interface instances
@@ -80,12 +90,18 @@ class Interface(Blocks):
         model repos (if src is "models") or Space repos (if src is "spaces"). The input
         and output components are automatically loaded from the repo.
         Parameters:
-        name (str): the name of the model (e.g. "gpt2"), can include the `src` as prefix (e.g. "models/gpt2")
-        src (str | None): the source of the model: `models` or `spaces` (or empty if source is provided as a prefix in `name`)
-        api_key (str | None): optional api key for use with Hugging Face Hub
-        alias (str | None): optional string used as the name of the loaded model instead of the default name
+            name: the name of the model (e.g. "gpt2"), can include the `src` as prefix (e.g. "models/gpt2")
+            src: the source of the model: `models` or `spaces` (or empty if source is provided as a prefix in `name`)
+            api_key: optional api key for use with Hugging Face Hub
+            alias: optional string used as the name of the loaded model instead of the default name
         Returns:
-        (gradio.Interface): a Gradio Interface object for the given model
+            a Gradio Interface object for the given model
+        Example:
+            import gradio as gr
+            description = "Story generation with GPT"
+            examples = [["An adventurer is approached by a mysterious stranger in the tavern for a new quest."]]
+            demo = gr.Interface.load("models/EleutherAI/gpt-neo-1.3B", description=description, examples=examples)
+            demo.launch()
         """
         return super().load(name=name, src=src, api_key=api_key, alias=alias, **kwargs)
 
@@ -95,9 +111,14 @@ class Interface(Blocks):
         Class method that constructs an Interface from a Hugging Face transformers.Pipeline object.
         The input and output components are automatically determined from the pipeline.
         Parameters:
-        pipeline (transformers.Pipeline): the pipeline object to use.
+            pipeline: the pipeline object to use.
         Returns:
-        (gradio.Interface): a Gradio Interface object from the given Pipeline
+            a Gradio Interface object from the given Pipeline
+        Example:
+            import gradio as gr
+            from transformers import pipeline
+            pipe = pipeline("image-classification")
+            gr.Interface.from_pipeline(pipe).launch()
         """
         interface_info = load_from_pipeline(pipeline)
         kwargs = dict(interface_info, **kwargs)
@@ -126,34 +147,37 @@ class Interface(Blocks):
         flagging_dir: str = "flagged",
         flagging_callback: FlaggingCallback = CSVLogger(),
         analytics_enabled: Optional[bool] = None,
-        _repeat_outputs_per_model: bool = True,
         **kwargs,
     ):
         """
         Parameters:
-        fn (Callable): the function to wrap an interface around. Often a machine learning model's prediction function.
-        inputs (str | Component | List[str] | List[Component] | None): a single Gradio component, or list of Gradio components. Components can either be passed as instantiated objects, or referred to by their string shortcuts. The number of input components should match the number of parameters in fn. If set to None, then only the output components will be displayed.
-        outputs (str | Component | List[str] | List[Component] | None): a single Gradio component, or list of Gradio components. Components can either be passed as instantiated objects, or referred to by their string shortcuts. The number of output components should match the number of values returned by fn. If set to None, then only the input components will be displayed.
-        examples (List[List[Any]] | str | None): sample inputs for the function; if provided, appear below the UI components and can be clicked to populate the interface. Should be nested list, in which the outer list consists of samples and each inner list consists of an input corresponding to each input component. A string path to a directory of examples can also be provided. If there are multiple input components and a directory is provided, a log.csv file must be present in the directory to link corresponding inputs.
-        cache_examples (bool | None): If True, caches examples in the server for fast runtime in examples. The default option in HuggingFace Spaces is True. The default option elsewhere is False.
-        examples_per_page (int): If examples are provided, how many to display per page.
-        live (bool): whether the interface should automatically rerun if any of the inputs change.
-        interpretation (Callable | str): function that provides interpretation explaining prediction output. Pass "default" to use simple built-in interpreter, "shap" to use a built-in shapley-based interpreter, or your own custom interpretation function.
-        num_shap (float): a multiplier that determines how many examples are computed for shap-based interpretation. Increasing this value will increase shap runtime, but improve results. Only applies if interpretation is "shap".
-        title (str | None): a title for the interface; if provided, appears above the input and output components in large font.
-        description (str | None): a description for the interface; if provided, appears above the input and output components and beneath the title in regular font. Accepts Markdown and HTML content.
-        article (str | None): an expanded article explaining the interface; if provided, appears below the input and output components in regular font. Accepts Markdown and HTML content.
-        thumbnail (str | None): path or url to image to use as display image when the web demo is shared on social media.
-        theme (str | None): Theme to use - right now, only "default" is supported. Can be set with the GRADIO_THEME environment variable.
-        css (str | None): custom css or path to custom css file to use with interface.
-        allow_flagging (str | None): one of "never", "auto", or "manual". If "never" or "auto", users will not see a button to flag an input and output. If "manual", users will see a button to flag. If "auto", every prediction will be automatically flagged. If "manual", samples are flagged when the user clicks flag button. Can be set with environmental variable GRADIO_ALLOW_FLAGGING; otherwise defaults to "manual".
-        flagging_options (List[str] | None): if provided, allows user to select from the list of options when flagging. Only applies if allow_flagging is "manual".
-        flagging_dir (str): what to name the directory where flagged data is stored.
-        flagging_callback (FlaggingCallback): An instance of a subclass of FlaggingCallback which will be called when a sample is flagged. By default logs to a local CSV file.
-        analytics_enabled (bool | None): Whether to allow basic telemetry. If None, will use GRADIO_ANALYTICS_ENABLED environment variable if defined, or default to True.
+            fn: the function to wrap an interface around. Often a machine learning model's prediction function.
+            inputs: a single Gradio component, or list of Gradio components. Components can either be passed as instantiated objects, or referred to by their string shortcuts. The number of input components should match the number of parameters in fn. If set to None, then only the output components will be displayed.
+            outputs: a single Gradio component, or list of Gradio components. Components can either be passed as instantiated objects, or referred to by their string shortcuts. The number of output components should match the number of values returned by fn. If set to None, then only the input components will be displayed.
+            examples: sample inputs for the function; if provided, appear below the UI components and can be clicked to populate the interface. Should be nested list, in which the outer list consists of samples and each inner list consists of an input corresponding to each input component. A string path to a directory of examples can also be provided. If there are multiple input components and a directory is provided, a log.csv file must be present in the directory to link corresponding inputs.
+            cache_examples: If True, caches examples in the server for fast runtime in examples. The default option in HuggingFace Spaces is True. The default option elsewhere is False.
+            examples_per_page: If examples are provided, how many to display per page.
+            live: whether the interface should automatically rerun if any of the inputs change.
+            interpretation: function that provides interpretation explaining prediction output. Pass "default" to use simple built-in interpreter, "shap" to use a built-in shapley-based interpreter, or your own custom interpretation function.
+            num_shap: a multiplier that determines how many examples are computed for shap-based interpretation. Increasing this value will increase shap runtime, but improve results. Only applies if interpretation is "shap".
+            title: a title for the interface; if provided, appears above the input and output components in large font. Also used as the tab title when opened in a browser window.
+            description: a description for the interface; if provided, appears above the input and output components and beneath the title in regular font. Accepts Markdown and HTML content.
+            article: an expanded article explaining the interface; if provided, appears below the input and output components in regular font. Accepts Markdown and HTML content.
+            thumbnail: path or url to image to use as display image when the web demo is shared on social media.
+            theme: Theme to use - right now, only "default" is supported. Can be set with the GRADIO_THEME environment variable.
+            css: custom css or path to custom css file to use with interface.
+            allow_flagging: one of "never", "auto", or "manual". If "never" or "auto", users will not see a button to flag an input and output. If "manual", users will see a button to flag. If "auto", every prediction will be automatically flagged. If "manual", samples are flagged when the user clicks flag button. Can be set with environmental variable GRADIO_ALLOW_FLAGGING; otherwise defaults to "manual".
+            flagging_options: if provided, allows user to select from the list of options when flagging. Only applies if allow_flagging is "manual".
+            flagging_dir: what to name the directory where flagged data is stored.
+            flagging_callback: An instance of a subclass of FlaggingCallback which will be called when a sample is flagged. By default logs to a local CSV file.
+            analytics_enabled: Whether to allow basic telemetry. If None, will use GRADIO_ANALYTICS_ENABLED environment variable if defined, or default to True.
         """
         super().__init__(
-            analytics_enabled=analytics_enabled, mode="interface", css=css, **kwargs
+            analytics_enabled=analytics_enabled,
+            mode="interface",
+            css=css,
+            title=title,
+            **kwargs,
         )
 
         if inspect.iscoroutinefunction(fn):
@@ -170,14 +194,13 @@ class Interface(Blocks):
             inputs = []
             self.interface_type = self.InterfaceTypes.OUTPUT_ONLY
 
-        if not isinstance(fn, list):
-            fn = [fn]
-        else:
+        if isinstance(fn, list):
             raise DeprecationWarning(
                 "The `fn` parameter only accepts a single function, support for a list "
                 "of functions has been deprecated. Please use gradio.mix.Parallel "
                 "instead."
             )
+
         if not isinstance(inputs, list):
             inputs = [inputs]
         if not isinstance(outputs, list):
@@ -195,7 +218,7 @@ class Interface(Blocks):
                 raise ValueError(
                     "If using 'state', there must be exactly one state input and one state output."
                 )
-            default = utils.get_default_args(fn[0])[inputs.index("state")]
+            default = utils.get_default_args(fn)[inputs.index("state")]
             state_variable = Variable(value=default)
             inputs[inputs.index("state")] = state_variable
             outputs[outputs.index("state")] = state_variable
@@ -236,9 +259,6 @@ class Interface(Blocks):
             for o in self.output_components:
                 o.interactive = False  # Force output components to be non-interactive
 
-        if _repeat_outputs_per_model:
-            self.output_components *= len(fn)
-
         if (
             interpretation is None
             or isinstance(interpretation, list)
@@ -253,10 +273,9 @@ class Interface(Blocks):
             raise ValueError("Invalid value for parameter: interpretation")
 
         self.api_mode = False
-        self.predict = fn
-        self.predict_durations = [[0, 0]] * len(fn)
-        self.function_names = [func.__name__ for func in fn]
-        self.__name__ = ", ".join(self.function_names)
+        self.fn = fn
+        self.fn_durations = [0, 0]
+        self.__name__ = fn.__name__
         self.live = live
         self.title = title
 
@@ -291,53 +310,7 @@ class Interface(Blocks):
         if not (self.theme == "default"):
             warnings.warn("Currently, only the 'default' theme is supported.")
 
-        if examples is None or (
-            isinstance(examples, list)
-            and (len(examples) == 0 or isinstance(examples[0], list))
-        ):
-            self.examples = examples
-        elif (
-            isinstance(examples, list) and len(self.input_components) == 1
-        ):  # If there is only one input component, examples can be provided as a regular list instead of a list of lists
-            self.examples = [[e] for e in examples]
-        elif isinstance(examples, str):
-            if not os.path.exists(examples):
-                raise FileNotFoundError(
-                    "Could not find examples directory: " + examples
-                )
-            log_file = os.path.join(examples, "log.csv")
-            if not os.path.exists(log_file):
-                if len(self.input_components) == 1:
-                    exampleset = [
-                        [os.path.join(examples, item)] for item in os.listdir(examples)
-                    ]
-                else:
-                    raise FileNotFoundError(
-                        "Could not find log file (required for multiple inputs): "
-                        + log_file
-                    )
-            else:
-                with open(log_file) as logs:
-                    exampleset = list(csv.reader(logs))
-                    exampleset = exampleset[1:]  # remove header
-            for i, example in enumerate(exampleset):
-                for j, (component, cell) in enumerate(
-                    zip(
-                        self.input_components + self.output_components,
-                        example,
-                    )
-                ):
-                    exampleset[i][j] = component.restore_flagged(
-                        examples,
-                        cell,
-                        None,
-                    )
-            self.examples = exampleset
-        else:
-            raise ValueError(
-                "Examples argument must either be a directory or a nested "
-                "list, where each sublist represents a set of inputs."
-            )
+        self.examples = examples
         self.num_shap = num_shap
         self.examples_per_page = examples_per_page
 
@@ -411,7 +384,7 @@ class Interface(Blocks):
         utils.version_check()
         Interface.instances.add(self)
 
-        param_names = inspect.getfullargspec(self.predict[0])[0]
+        param_names = inspect.getfullargspec(self.fn)[0]
         for component, param_name in zip(self.input_components, param_names):
             if component.label is None:
                 component.label = param_name
@@ -422,9 +395,6 @@ class Interface(Blocks):
                 else:
                     component.label = "output " + str(i)
 
-        if self.cache_examples and examples:
-            cache_interface_examples(self)
-
         if self.allow_flagging != "never":
             if self.interface_type == self.InterfaceTypes.UNIFIED:
                 self.flagging_callback.setup(self.input_components, self.flagging_dir)
@@ -621,34 +591,16 @@ class Interface(Blocks):
                 non_state_inputs = [
                     c for c in self.input_components if not isinstance(c, Variable)
                 ]
-
-                examples = Dataset(
-                    components=non_state_inputs,
-                    samples=self.examples,
-                    type="index",
-                )
-
-                def load_example(example_id):
-                    processed_examples = [
-                        component.preprocess_example(sample)
-                        for component, sample in zip(
-                            self.input_components, self.examples[example_id]
-                        )
-                    ]
-                    if self.cache_examples:
-                        processed_examples += load_from_cache(self, example_id)
-                    if len(processed_examples) == 1:
-                        return processed_examples[0]
-                    else:
-                        return processed_examples
-
-                examples.click(
-                    load_example,
-                    inputs=[examples],
-                    outputs=non_state_inputs
-                    + (self.output_components if self.cache_examples else []),
-                    _postprocess=False,
-                    queue=False,
+                non_state_outputs = [
+                    c for c in self.output_components if not isinstance(c, Variable)
+                ]
+                self.examples_handler = Examples(
+                    examples=examples,
+                    inputs=non_state_inputs,
+                    outputs=non_state_outputs,
+                    fn=self.fn,
+                    cache_examples=self.cache_examples,
+                    examples_per_page=examples_per_page,
                 )
 
             if self.interpretation:
@@ -680,9 +632,7 @@ class Interface(Blocks):
         return self.__repr__()
 
     def __repr__(self):
-        repr = "Gradio Interface for: {}".format(
-            ", ".join(fn.__name__ for fn in self.predict)
-        )
+        repr = f"Gradio Interface for: {self.__name__}"
         repr += "\n" + "-" * len(repr)
         repr += "\ninputs:"
         for component in self.input_components:
@@ -700,52 +650,39 @@ class Interface(Blocks):
         """
         Runs the prediction function with the given (already processed) inputs.
         Parameters:
-        processed_input (list): A list of processed inputs.
-        called_directly (bool): Whether the prediction is being called
-            directly (i.e. as a function, not through the GUI).
+            processed_input (list): A list of processed inputs.
+            called_directly (bool): Whether the prediction is being called directly (i.e. as a function, not through the GUI).
         Returns:
-        predictions (list): A list of predictions (not post-processed).
+            predictions (list): A list of predictions (not post-processed).
         """
         if self.api_mode:  # Serialize the input
             processed_input = [
                 input_component.serialize(processed_input[i], called_directly)
                 for i, input_component in enumerate(self.input_components)
             ]
-        predictions = []
-        output_component_counter = 0
 
-        for predict_fn in self.predict:
-            prediction = predict_fn(*processed_input)
+        prediction = self.fn(*processed_input)
 
-            if len(self.output_components) == len(self.predict) or prediction is None:
-                prediction = [prediction]
+        if prediction is None or len(self.output_components) == 1:
+            prediction = [prediction]
 
-            if self.api_mode:  # Serialize the input
-                prediction_ = copy.deepcopy(prediction)
-                prediction = []
+        if self.api_mode:  # Deerialize the input
+            prediction = [
+                output_component.deserialize(prediction[i])
+                for i, output_component in enumerate(self.output_components)
+            ]
 
-                # Done this way to handle both single interfaces with multiple outputs and Parallel() interfaces
-                for pred in prediction_:
-                    prediction.append(
-                        self.output_components[output_component_counter].deserialize(
-                            pred
-                        )
-                    )
-                    output_component_counter += 1
-
-            predictions.extend(prediction)
-
-        return predictions
+        return prediction
 
     def process(self, raw_input: List[Any]) -> Tuple[List[Any], List[float]]:
         """
         First preprocesses the input, then runs prediction using
         self.run_prediction(), then postprocesses the output.
         Parameters:
-        raw_input: a list of raw inputs to process and apply the prediction(s) on.
+            raw_input: a list of raw inputs to process and apply the prediction(s) on.
         Returns:
-        processed output: a list of processed  outputs to return as the prediction(s).
-        duration: a list of time deltas measuring inference time for each prediction fn.
+            processed output: a list of processed  outputs to return as the prediction(s).
+            duration: a list of time deltas measuring inference time for each prediction fn.
         """
         processed_input = [
             input_component.preprocess(raw_input[i])
@@ -773,19 +710,17 @@ class Interface(Blocks):
         Passes a few samples through the function to test if the inputs/outputs
         components are consistent with the function parameter and return values.
         """
-        for predict_fn in self.predict:
-            print("Test launch: {}()...".format(predict_fn.__name__), end=" ")
-            raw_input = []
-            for input_component in self.input_components:
-                if input_component.test_input is None:
-                    print("SKIPPED")
-                    break
-                else:
-                    raw_input.append(input_component.test_input)
+        print("Test launch: {}()...".format(self.__name__), end=" ")
+        raw_input = []
+        for input_component in self.input_components:
+            if input_component.test_input is None:
+                print("SKIPPED")
+                break
             else:
-                self.process(raw_input)
-                print("PASSED")
-                continue
+                raw_input.append(input_component.test_input)
+        else:
+            self.process(raw_input)
+            print("PASSED")
 
     def integrate(self, comet_ml=None, wandb=None, mlflow=None) -> None:
         """
@@ -841,10 +776,12 @@ class Interface(Blocks):
             utils.integration_analytics(data)
 
 
+@document()
 class TabbedInterface(Blocks):
     """
     A TabbedInterface is created by providing a list of Interfaces, each of which gets
     rendered in a separate tab.
+    Demos: sst_or_tts
     """
 
     def __init__(
@@ -852,10 +789,10 @@ class TabbedInterface(Blocks):
     ):
         """
         Parameters:
-        interface_list (List[Interface]): a list of interfaces to be rendered in tabs.
-        tab_names (List[str] | None): a list of tab names. If None, the tab names will be "Tab 1", "Tab 2", etc.
+            interface_list: a list of interfaces to be rendered in tabs.
+            tab_names: a list of tab names. If None, the tab names will be "Tab 1", "Tab 2", etc.
         Returns:
-        (gradio.TabbedInterface): a Gradio Tabbed Interface for the given interfaces
+            a Gradio Tabbed Interface for the given interfaces
         """
         if tab_names is None:
             tab_names = ["Tab {}".format(i) for i in range(len(interface_list))]
