@@ -3,23 +3,24 @@
 from __future__ import annotations
 
 import asyncio
+import copy
 import inspect
 import json
 import json.decoder
 import os
+import pkgutil
 import random
-import sys
 import warnings
 from copy import deepcopy
 from distutils.version import StrictVersion
 from enum import Enum
-from typing import TYPE_CHECKING, Any, Callable, Dict, Generator, List, NewType, Type
+from importlib.metadata import version
+from typing import TYPE_CHECKING, Any, Callable, Dict, Generator, NewType, Tuple, Type
 
 import aiohttp
 import analytics
 import fsspec.asyn
 import httpx
-import pkg_resources
 import requests
 from pydantic import BaseModel, Json, parse_obj_as
 
@@ -38,7 +39,9 @@ JSON_PATH = os.path.join(os.path.dirname(gradio.__file__), "launches.json")
 
 def version_check():
     try:
-        current_pkg_version = pkg_resources.require("gradio")[0].version
+        current_pkg_version = (
+            pkgutil.get_data(__name__, "version.txt").decode("ascii").strip()
+        )
         latest_pkg_version = requests.get(url=PKG_VERSION_URL).json()["version"]
         if StrictVersion(latest_pkg_version) > StrictVersion(current_pkg_version):
             print(
@@ -49,10 +52,6 @@ def version_check():
                 )
             )
             print("--------")
-    except pkg_resources.DistributionNotFound:
-        warnings.warn(
-            "gradio is not setup or installed properly. Unable to get version info."
-        )
     except json.decoder.JSONDecodeError:
         warnings.warn("unable to parse version details from package URL.")
     except KeyError:
@@ -195,10 +194,24 @@ def get_default_args(func: Callable) -> Dict[str, Any]:
     ]
 
 
-def assert_configs_are_equivalent_besides_ids(config1, config2):
-    """Allows you to test if two different Blocks configs produce the same demo."""
-    assert config1["mode"] == config2["mode"], "Modes are different"
-    assert config1["theme"] == config2["theme"], "Themes are different"
+def assert_configs_are_equivalent_besides_ids(
+    config1: Dict, config2: Dict, root_keys: Tuple = ("mode", "theme")
+):
+    """Allows you to test if two different Blocks configs produce the same demo.
+
+    Parameters:
+    config1 (dict): nested dict with config from the first Blocks instance
+    config2 (dict): nested dict with config from the second Blocks instance
+    root_keys (Tuple): an interable consisting of which keys to test for equivalence at
+        the root level of the config. By default, only "mode" and "theme" are tested,
+        so keys like "version" are ignored.
+    """
+    config1 = copy.deepcopy(config1)
+    config2 = copy.deepcopy(config2)
+
+    for key in root_keys:
+        assert config1[key] == config2[key], f"Configs have different: {key}"
+
     assert len(config1["components"]) == len(
         config2["components"]
     ), "# of components are different"
@@ -210,13 +223,13 @@ def assert_configs_are_equivalent_besides_ids(config1, config2):
         mapping[c1["id"]] = c2["id"]
         c1.pop("id")
         c2.pop("id")
-        assert c1 == c2, "{} does not match {}".format(c1, c2)
+        assert c1 == c2, f"{c1} does not match {c2}"
 
     def same_children_recursive(children1, chidren2, mapping):
         for child1, child2 in zip(children1, chidren2):
-            assert mapping[child1["id"]] == child2["id"], "{} does not match {}".format(
-                child1, child2
-            )
+            assert (
+                mapping[child1["id"]] == child2["id"]
+            ), f"{child1} does not match {child2}"
             if "children" in child1 or "children" in child2:
                 same_children_recursive(child1["children"], child2["children"], mapping)
 
@@ -225,13 +238,18 @@ def assert_configs_are_equivalent_besides_ids(config1, config2):
     same_children_recursive(children1, children2, mapping)
 
     for d1, d2 in zip(config1["dependencies"], config2["dependencies"]):
-        for t1, t2 in zip(d1["targets"], d2["targets"]):
-            assert mapping[t1] == t2, "{} does not match {}".format(d1, d2)
-        assert d1["trigger"] == d2["trigger"], "{} does not match {}".format(d1, d2)
-        for i1, i2 in zip(d1["inputs"], d2["inputs"]):
-            assert mapping[i1] == i2, "{} does not match {}".format(d1, d2)
-        for o1, o2 in zip(d1["outputs"], d2["outputs"]):
-            assert mapping[o1] == o2, "{} does not match {}".format(d1, d2)
+        for t1, t2 in zip(d1.pop("targets"), d2.pop("targets")):
+            assert mapping[t1] == t2, f"{d1} does not match {d2}"
+        for i1, i2 in zip(d1.pop("inputs"), d2.pop("inputs")):
+            assert mapping[i1] == i2, f"{d1} does not match {d2}"
+        for o1, o2 in zip(d1.pop("outputs"), d2.pop("outputs")):
+            assert mapping[o1] == o2, f"{d1} does not match {d2}"
+
+        # status tracker is popped since we allow it to have different ids
+        d1.pop("status_tracker", None)
+        d2.pop("status_tracker", None)
+
+        assert d1 == d2, f"{d1} does not match {d2}"
 
     return True
 
